@@ -1,7 +1,10 @@
 """packaging information"""
+
+import os.path as osp
+
 # Things that change more often go here.
 copyright = """
-Copyright (C) 2008-2010, 2013, 2015, 2020 Rocky Bernstein <rocky@gnu.org>.
+Copyright (C) 2008-2010, 2013, 2015, 2020, 2022 Rocky Bernstein <rocky@gnu.org>.
 """
 classifiers = [
     "Development Status :: 5 - Production/Stable",
@@ -21,41 +24,34 @@ classifiers = [
     "Programming Language :: Python :: 3.6 ",
     "Programming Language :: Python :: 3.7 ",
     "Programming Language :: Python :: 3.8 ",
+    "Programming Language :: Python :: 3.9 ",
+    "Programming Language :: Python :: 3.10 ",
 ]
 
+
+def get_srcdir():
+    filename = osp.normcase(osp.dirname(osp.abspath(__file__)))
+    return osp.realpath(filename)
+
+
+def read(*rnames):
+    return open(osp.join(get_srcdir(), *rnames)).read()
+
+
+exec(read("columnize/version.py"))
+
 # The rest in alphabetic order
 author = "Rocky Bernstein"
 author_email = "rocky@gnu.org"
-ftp_url = None
 license = "MIT"
-mailing_list = None
 modname = "columnize"
 
 short_desc = "Format a simple (i.e. not nested) list into aligned columns."
 py_modules = [modname]
-
-# VERSION.py sets variable VERSION.
-import os.path
-
-exec(
-    compile(
-        open(os.path.join(os.path.dirname(__file__), "VERSION.py")).read(),
-        os.path.join(os.path.dirname(__file__), "VERSION.py"),
-        "exec",
-    )
-)
-
-tests_require = ["mock"]
+test_requires = ["pytest"]
 web = "https://github.com/rocky/pycolumnize"
-# tracebacks in zip files are funky and not debuggable
-zip_safe = False
-
-
-def read(*rnames):
-    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()
-
 
 readme = "README.txt"
-if os.path.exists("README.rst"):
+if osp.exists("README.rst"):
     readme = "README.rst"
 long_description = read(readme) + "\n"
